@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
 import anyjson
+import atexit
 import os
 import sys
 
@@ -14,6 +15,21 @@ except ImportError:
     anyjson.force_implementation('simplejson')
 
 
+def teardown():
+    # Workaround for multiprocessing bug where logging
+    # is attempted after global already collected at shutdown.
+    cancelled = set()
+    try:
+        import multiprocessing.util
+        cancelled.add(multiprocessing.util._exit_function)
+    except (AttributeError, ImportError):
+        pass
+
+    atexit._exithandlers[:] = [
+        e for e in atexit._exithandlers if e[0] not in cancelled
+    ]
+
+
 def find_distribution_modules(name=__name__, file=__file__):
     current_dist_depth = len(name.split('.')) - 1
     current_dist = os.path.join(os.path.dirname(file),
