@@ -216,7 +216,7 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
         try:
             return fun(*args, **kwargs)
         except catch, exc:
-            if max_retries is not None and retries > max_retries:
+            if max_retries is not None and retries >= max_retries:
                 raise
             if callback:
                 callback()
